@@ -463,7 +463,7 @@ class Outcar(object):
         for ii, i in enumerate(self.data):
             if "Electric field gradients after diagonalization" in i:
                 tmp = ii
-        arr = self.data[tmp + 5 : tmp + 5 + nions]
+        arr = self.data[tmp + 5: tmp + 5 + nions]
         efg_arr = []
         for i in arr:
             if std_conv:
@@ -495,7 +495,7 @@ class Outcar(object):
         for ii, i in enumerate(self.data):
             if "Electric field gradients (V/A^2)" in i:
                 tmp = ii
-        arr = self.data[tmp + 4 : tmp + 4 + nions]
+        arr = self.data[tmp + 4: tmp + 4 + nions]
         efg_arr = []
         for i in arr:
             line = i.split()
@@ -518,7 +518,7 @@ class Outcar(object):
                 in i
             ):
                 tmp = ii
-        arr = self.data[tmp + 4 : tmp + 4 + nions]
+        arr = self.data[tmp + 4: tmp + 4 + nions]
         quad_arr = []
         for i in arr:
             tmp = [i.split()[1], i.split()[2], i.split()[3]]
@@ -1237,7 +1237,7 @@ class Vasprun(object):
         for i in range(natoms):
             for j in range(natoms):
                 force_constants[i, j] = hessian[
-                    i * 3 : (i + 1) * 3, j * 3 : (j + 1) * 3
+                    i * 3: (i + 1) * 3, j * 3: (j + 1) * 3
                 ]
         masses = [Specie(i).atomic_mass for i in struct.elements]
         # print("Vasp masses", masses)
@@ -2092,13 +2092,28 @@ def parse_raman_dat(
     Parse vasp_raman.dat .
 
     generated by https://github.com/raman-sc/VASP
+
+    Activities to Intensities: J. At. Mol. Sci. 3 (2012) 1-22
+    Intensity = const0 * (nu0-nu)**4/nu * 1/(1-exp(-h*c*nu/(kB*T))) * activity
+    Data for computing intensities, as in Materials Project's paper:
+      T=300K,
+      nu0=18796.9925 cm-1
     """
+    temp = 300.0
+    nu0 = 18796.9925
+    # hc = Plank's constant * speed of light
+    # hc_over_kB = h*c/Boltzman_constant
+    hc_over_kB = 1.4388003592  # cm/s
+    # A good, aritrary choice for const0 is 10**(-14)
+    const0 = 10 ** (-14)
+
     f = open(vasp_raman_path, "r")
     lines = f.read().splitlines()
     f.close()
     info = {}
     freqs = []
     activity = []
+    intensity = []
     alpha = []
     beta2 = []
     for i in lines:
@@ -2108,6 +2123,12 @@ def parse_raman_dat(
             alpha.append(float(tmp[2]))
             beta2.append(float(tmp[3]))
             activity.append(float(tmp[4]))
+            nu = float(tmp[1])
+            AA1 = const0 * (nu0 - nu) ** 4 / nu
+            exp1 = np.exp(-hc_over_kB * nu / temp)
+            AA2 = 1.0 / (1.0 - exp1)
+            intensita = AA1 * AA2 * float(tmp[4])
+            intensity.append(intensita)
     freqs = np.array(freqs)
     activity = np.array(activity)
     indices = np.arange(0, len(activity) - 1)
@@ -2121,6 +2142,7 @@ def parse_raman_dat(
     info["alpha"] = alpha
     info["beta2"] = beta2
     info["indices"] = indices
+    info["intensity"] = intensity
     return info
 
 
